@@ -1,13 +1,13 @@
 <?php
-$host = '127.0.0.1';
+//$host = '127.0.0.1';
 //$host = "wiki.swoole.com";
-//$host = 'www.jd.com';
+$host = 'www.jd.com';
 
-$port = 9501;
-//$port = 443;
+//$port = 9501;
+$port = 443;
 
-$ssl = false;
-//$ssl = true;
+//$ssl = false;
+$ssl = true;
 
 $array = array(
     "host" => $host,
@@ -20,7 +20,7 @@ $array = array(
 $list = array();
 for($i = 0; $i < 1; $i++) {
     $client = new swoole_http2_client($host , $port, $ssl);
-    
+
     $client->setHeaders($array);
     //$client->setCookies(array("a" => "1", "b" => "2"));
 
@@ -28,19 +28,19 @@ for($i = 0; $i < 1; $i++) {
         echo "#{$client->sock} hello world 1\n";
         //var_dump($o);
         echo $o->body;
-        //$client->close();
+        $client->close();
     });
 
-    $client->post("/", $array, function ($o) use($client) {
-        echo "{$client->sock} hello world 2\n";  
+    /*$client->post("/", $array, function ($o) use($client) {
+        echo "{$client->sock} hello world 2\n";
     });
-    
+
+
     $client->post("/", $array, function ($o) use($client) {
         echo "{$client->sock} hello world 3\n";
         echo $o->body;
-        $client->close();        
-    });
-
+        $client->close();
+    });*/
     $list[] = $client;
 }
 
