@@ -44,7 +44,7 @@ static bool protect_stack(void *top, size_t stack_size, uint32_t page)
         swoole_error_log(SW_LOG_ERROR, SW_ERROR_CO_PROTECT_STACK_FAILED, "getpagesize() failed.");
         return false;
     }
-
+#ifdef PROT_NONE
     void *protect_page_addr = ((size_t) top & 0xfff) ? (void*) (((size_t) top & ~(size_t) 0xfff) + 0x1000) : top;
     if (-1 == mprotect(protect_page_addr, SwooleG.pagesize * page, PROT_NONE))
     {
@@ -57,10 +57,12 @@ static bool protect_stack(void *top, size_t stack_size, uint32_t page)
         swDebug("origin_addr:%p, align_addr:%p, page_size:%d, protect_page:%u", top, protect_page_addr, page, SwooleG.pagesize);
         return true;
     }
+#endif
 }
 static bool unprotect_stack(void *top, uint32_t page)
 {
     void *protect_page_addr = ((size_t) top & 0xfff) ? (void*) (((size_t) top & ~(size_t) 0xfff) + 0x1000) : top;
+#ifdef PROT_READ
     if (-1 == mprotect(protect_page_addr, SwooleG.pagesize * page, PROT_READ | PROT_WRITE))
     {
         swSysError("mprotect() failed: origin_addr:%p, align_addr:%p, page_size:%d, protect_page:%u.", top,
@@ -72,6 +74,7 @@ static bool unprotect_stack(void *top, uint32_t page)
         swDebug("origin_addr:%p, align_addr:%p, page_size:%d, protect_page:%u.", top, protect_page_addr, page, SwooleG.pagesize);
         return true;
     }
+#endif
 }
 class Context
 {
@@ -106,4 +109,3 @@ private:
 };
 //namespace end
 }
-
