@@ -320,8 +320,6 @@ int swFactory_end(swFactory *factory, int fd);
 int swFactory_check_callback(swFactory *factory);
 
 int swFactoryProcess_create(swFactory *factory, int worker_num);
-int swFactoryThread_create(swFactory *factory, int writer_num);
-
 
 //------------------------------------Server-------------------------------------------
 enum swServer_callback_type
@@ -555,11 +553,15 @@ struct _swServer
      */
     char *upload_tmp_dir;
 
+    /**
+     * http compression level for gzip/br
+     */
+    uint8_t http_compression_level;
+
     /**
      * http static file directory
      */
     char *document_root;
-    uint8_t http_gzip_level;
     uint16_t document_root_len;
 
     /**
@@ -961,6 +963,7 @@ void swServer_set_callback_onClose(swServer *serv, void (*callback)(swServer *,
 
 int swWorker_create(swWorker *worker);
 int swWorker_onTask(swFactory *factory, swEventData *task);
+void swWorker_stop(swWorker *worker);
 
 static sw_inline swConnection *swWorker_get_connection(swServer *serv, int session_id)
 {
@@ -971,14 +974,10 @@ static sw_inline swConnection *swWorker_get_connection(swServer *serv, int sessi
 
 static sw_inline swString *swWorker_get_buffer(swServer *serv, int reactor_id)
 {
-    if (serv->factory_mode == SW_MODE_SINGLE)
+    if (serv->factory_mode == SW_MODE_BASE)
     {
         return SwooleWG.buffer_input[0];
     }
-    else if (serv->factory_mode == SW_MODE_THREAD)
-    {
-        return SwooleTG.buffer_input[reactor_id];
-    }
     else
     {
         return SwooleWG.buffer_input[reactor_id];
