@@ -90,7 +90,7 @@ void *swArray_fetch(swArray *array, uint32_t n)
     {
         return NULL;
     }
-    return array->pages[page] + (swArray_offset(array, n) * array->item_size);
+    return (char*) array->pages[page] + (swArray_offset(array, n) * array->item_size);
 }
 
 /**
@@ -106,7 +106,7 @@ int swArray_append(swArray *array, void *data)
         return SW_ERR;
     }
     array->item_num++;
-    memcpy(array->pages[page] + (swArray_offset(array, n) * array->item_size), data, array->item_size);
+    memcpy((char*) array->pages[page] + (swArray_offset(array, n) * array->item_size), data, array->item_size);
     return n;
 }
 
@@ -119,7 +119,7 @@ int swArray_store(swArray *array, uint32_t n, void *data)
         swWarn("fetch index[%d] out of array", n);
         return SW_ERR;
     }
-    memcpy(array->pages[page] + (swArray_offset(array, n) * array->item_size), data, array->item_size);
+    memcpy((char*) array->pages[page] + (swArray_offset(array, n) * array->item_size), data, array->item_size);
     return SW_OK;
 }
 
@@ -139,7 +139,7 @@ void *swArray_alloc(swArray *array, uint32_t n)
         swWarn("fetch index[%d] out of array", n);
         return NULL;
     }
-    return array->pages[page] + (swArray_offset(array, n) * array->item_size);
+    return (char*) array->pages[page] + (swArray_offset(array, n) * array->item_size);
 }
 
 void swArray_clear(swArray *array)
