@@ -108,6 +108,7 @@ bool Socket::socks5_handshake()
             buf[4] = ctx->l_target_host;
             buf += 5;
             memcpy(buf, ctx->target_host, ctx->l_target_host);
+            sw_free(ctx->target_host);
             buf += ctx->l_target_host;
             *(uint16_t *) buf = htons(ctx->target_port);
 
@@ -133,6 +134,7 @@ bool Socket::socks5_handshake()
         /**
          * response
          */
+        buf = ctx->buf;
         n = recv(buf, sizeof(ctx->buf));
         if (n <= 0)
         {
@@ -409,21 +411,21 @@ bool Socket::connect(string host, int port, int flags)
         swWarn("socket has already been bound to another coroutine #%d.", read_cid);
         return false;
     }
-    //enable socks5 proxy
+
     if (socks5_proxy)
     {
-        socks5_proxy->target_host = (char *) host.c_str();
+        //enable socks5 proxy
+        socks5_proxy->target_host = sw_strndup((char *) host.c_str(), host.size());
         socks5_proxy->l_target_host = host.size();
         socks5_proxy->target_port = port;
 
         host = socks5_proxy->host;
         port = socks5_proxy->port;
     }
-
-    //enable http proxy
-    if (http_proxy)
+    else if (http_proxy)
     {
-        http_proxy->target_host = (char *) host.c_str();
+        //enable http proxy
+        http_proxy->target_host = sw_strndup((char *) host.c_str(), host.size());
         http_proxy->l_target_host = host.size();
         http_proxy->target_port = port;
 
@@ -1445,6 +1447,7 @@ bool Socket::sendfile(char *filename, off_t offset, size_t length)
         else if (n == 0)
         {
             swWarn("sendfile return zero.");
+            ::close(file_fd);
             return false;
         }
         else if (errno != EAGAIN)
