@@ -395,6 +395,7 @@ static int swClient_inet_addr(swClient *cli, char *host, int port)
             return SW_OK;
         }
     }
+#ifndef _WIN32
     else if (cli->type == SW_SOCK_UNIX_STREAM || cli->type == SW_SOCK_UNIX_DGRAM)
     {
         cli->server_addr.addr.un.sun_family = AF_UNIX;
@@ -403,6 +404,7 @@ static int swClient_inet_addr(swClient *cli, char *host, int port)
         cli->server_addr.len = sizeof(cli->server_addr.addr.un.sun_path);
         return SW_OK;
     }
+#endif
     else
     {
         return SW_ERR;
@@ -504,10 +506,12 @@ static int swClient_close(swClient *cli)
         swString_free(cli->buffer);
         cli->buffer = NULL;
     }
+#ifndef _WIN32
     if (cli->type == SW_SOCK_UNIX_DGRAM)
     {
         unlink(cli->socket->info.addr.un.sun_path);
     }
+#endif
     if (cli->async)
     {
         //remove from reactor
@@ -752,14 +756,20 @@ static int swClient_tcp_connect_async(swClient *cli, char *host, int port, doubl
         }
         if (timeout > 0)
         {
-            if (SwooleG.timer.fd == 0)
-            {
-                swTimer_init((int) (timeout * 1000));
-            }
-            cli->timer = SwooleG.timer.add(&SwooleG.timer, (int) (timeout * 1000), 0, cli, swClient_onTimeout);
+            cli->timer = swTimer_add(&SwooleG.timer, (int) (timeout * 1000), 0, cli, swClient_onTimeout);
         }
         return SW_OK;
     }
+    else
+    {
+        cli->socket->active = 0;
+        cli->socket->removed = 1;
+        cli->close(cli);
+        if (cli->onError)
+        {
+            cli->onError(cli);
+        }
+    }
 
     return ret;
 }
@@ -955,6 +965,7 @@ static int swClient_udp_connect(swClient *cli, char *host, int port, double time
         swSocket_set_timeout(cli->socket->fd, timeout);
     }
 
+#ifndef _WIN32
     if (cli->type == SW_SOCK_UNIX_DGRAM)
     {
         struct sockaddr_un* client_addr = &cli->socket->info.addr.un;
@@ -968,6 +979,8 @@ static int swClient_udp_connect(swClient *cli, char *host, int port, double time
             return SW_ERR;
         }
     }
+#endif
+
     if (udp_connect != 1)
     {
         goto connect_ok;
@@ -993,9 +1006,13 @@ static int swClient_udp_connect(swClient *cli, char *host, int port, double time
     }
     else
     {
-        swSysError("connect() failed.");
         cli->socket->active = 0;
         cli->socket->removed = 1;
+        cli->close(cli);
+        if (cli->async && cli->onError)
+        {
+            cli->onError(cli);
+        }
         return SW_ERR;
     }
 }
