@@ -33,15 +33,18 @@ int swoole_sendfile(int out_fd, int in_fd, off_t *offset, size_t size)
     hdtr.trl_cnt = 0;
 #endif
 
-    //sent_bytes = (off_t)size;
-    swTrace("send file, out_fd:%d, in_fd:%d, offset:%ld, size:%ld", out_fd, in_fd, (long)*offset, (long)size);
 
     do_sendfile:
 #ifdef __MACH__
-    ret = sendfile(in_fd, out_fd, *offset, (long long *) &size, &hdtr, 0);
+    ret = sendfile(in_fd, out_fd, *offset, (off_t *) &size, &hdtr, 0);
 #else
     ret = sendfile(in_fd, out_fd, *offset, size, 0, &sent_bytes, 0);
 #endif
+
+    //sent_bytes = (off_t)size;
+    swTrace("send file, ret:%d, out_fd:%d, in_fd:%d, offset:%jd, size:%zu", ret, out_fd, in_fd, (intmax_t) *offset, size);
+
+    *offset += size;
     if (ret == -1)
     {
         if (errno == EAGAIN)
@@ -55,12 +58,11 @@ int swoole_sendfile(int out_fd, int in_fd, off_t *offset, size_t size)
         }
         else
         {
-            return -1;
+            return SW_ERR;
         }
     }
     else if (ret == 0)
     {
-        *offset += size;
         return size;
     }
     else
