@@ -706,11 +706,12 @@ static sw_inline uint32_t swoole_get_new_size(uint32_t old_size, int handle)
     return new_size;
 }
 
-void swoole_set_object(zval *object, void *ptr)
+void swoole_set_object(zval *zobject, void *ptr)
 {
-    int handle = Z_OBJ_HANDLE_P(object);
+    int handle = Z_OBJ_HANDLE_P(zobject);
     assert(handle < SWOOLE_OBJECT_MAX);
-    if (handle >= swoole_objects.size)
+
+    if (unlikely(handle >= swoole_objects.size))
     {
         uint32_t old_size = swoole_objects.size;
         uint32_t new_size = swoole_get_new_size(old_size, handle);
@@ -728,15 +729,20 @@ void swoole_set_object(zval *object, void *ptr)
         swoole_objects.array = new_ptr;
         swoole_objects.size = new_size;
     }
+    else if (ptr)
+    {
+        assert(swoole_objects.array[handle] == NULL);
+    }
+
     swoole_objects.array[handle] = ptr;
 }
 
-void swoole_set_property(zval *object, int property_id, void *ptr)
+void swoole_set_property(zval *zobject, int property_id, void *ptr)
 {
-    int handle = Z_OBJ_HANDLE_P(object);
+    int handle = Z_OBJ_HANDLE_P(zobject);
     assert(handle < SWOOLE_OBJECT_MAX);
 
-    if (handle >= swoole_objects.property_size[property_id])
+    if (unlikely(handle >= swoole_objects.property_size[property_id]))
     {
         uint32_t old_size = swoole_objects.property_size[property_id];
         uint32_t new_size = 0;
@@ -767,6 +773,11 @@ void swoole_set_property(zval *object, int property_id, void *ptr)
         swoole_objects.property_size[property_id] = new_size;
         swoole_objects.property[property_id] = new_ptr;
     }
+    else if (ptr)
+    {
+        assert(swoole_objects.property[property_id][handle] == NULL);
+    }
+
     swoole_objects.property[property_id][handle] = ptr;
 }
 
@@ -824,8 +835,7 @@ PHP_MINIT_FUNCTION(swoole)
     /**
      * mode type
      */
-    REGISTER_LONG_CONSTANT("SWOOLE_BASE", SW_MODE_SINGLE, CONST_CS | CONST_PERSISTENT);
-    REGISTER_LONG_CONSTANT("SWOOLE_THREAD", SW_MODE_THREAD, CONST_CS | CONST_PERSISTENT);
+    REGISTER_LONG_CONSTANT("SWOOLE_BASE", SW_MODE_BASE, CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("SWOOLE_PROCESS", SW_MODE_PROCESS, CONST_CS | CONST_PERSISTENT);
 
     /**
@@ -1371,21 +1381,15 @@ static uint32_t hashkit_one_at_a_time(const char *key, size_t key_length)
 static PHP_FUNCTION(swoole_hashcode)
 {
     char *data;
-    zend_size_t l_data;
+    size_t l_data;
     zend_long type = 0;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 2)
         Z_PARAM_STRING(data, l_data)
         Z_PARAM_OPTIONAL
         Z_PARAM_LONG(type)
-    ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|l", &data, &l_data, &type) == FAILURE)
-    {
-        return;
-    }
-#endif
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
+
     switch(type)
     {
     case 1:
@@ -1419,7 +1423,7 @@ PHP_FUNCTION(swoole_strerror)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|l", &swoole_errno, &error_type) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (error_type == 1)
     {
@@ -1442,7 +1446,7 @@ PHP_FUNCTION(swoole_get_mime_type)
     zend_long filename_len;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &filename, &filename_len) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     RETURN_STRING(swoole_get_mime_type(filename));
 }
@@ -1464,7 +1468,7 @@ PHP_FUNCTION(swoole_set_process_name)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|l", &name, &size) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (Z_STRLEN_P(name) == 0)
