@@ -302,14 +302,14 @@ static void php_swoole_aio_onDNSCompleted(swAio_event *event)
 {
     int64_t ret;
 
+    dns_request *dns_req = NULL;
     zval *retval = NULL, *zcallback = NULL;
     zval args[2];
-    dns_request *dns_req = NULL;
-
-    zval _zcontent;
+    zval _zcontent, *zcontent = &_zcontent;
 
     dns_req = (dns_request *) event->req;
     zcallback = dns_req->callback;
+    ZVAL_NULL(zcontent);
 
     ret = event->ret;
     if (ret < 0)
@@ -319,7 +319,6 @@ static void php_swoole_aio_onDNSCompleted(swAio_event *event)
     }
 
     args[0] = *dns_req->domain;
-    zval *zcontent = &_zcontent;
     if (ret < 0)
     {
         ZVAL_STRING(zcontent, "");
@@ -345,7 +344,7 @@ static void php_swoole_aio_onDNSCompleted(swAio_event *event)
     efree(dns_req);
     efree(event->buf);
 
-    if (zcontent)
+    if (!ZVAL_IS_NULL(zcontent))
     {
         zval_ptr_dtor(zcontent);
     }
@@ -358,21 +357,18 @@ static void php_swoole_aio_onDNSCompleted(swAio_event *event)
 static void php_swoole_aio_onFileCompleted(swAio_event *event)
 {
     int isEOF = SW_FALSE;
-    int64_t ret;
-
-    zval *retval = NULL, *zcallback = NULL, *zwriten = NULL;
-    zval *zcontent = NULL;
-    zval args[2];
-
-    zval _zcontent;
-    zval _zwriten;
-    bzero(&_zcontent, sizeof(zval));
-    bzero(&_zwriten, sizeof(zval));
-
+    int64_t ret = event->ret;
     file_request *file_req = event->object;
-    zcallback = file_req->callback;
 
-    ret = event->ret;
+    zval *retval = NULL, *zcallback = NULL;
+    zval args[2];
+    zval _zcontent, *zcontent = &_zcontent;
+    zval _zwriten, *zwriten = &_zwriten;
+
+    zcallback = file_req->callback;
+    ZVAL_NULL(zcontent);
+    ZVAL_NULL(zwriten);
+
     if (ret < 0)
     {
         SwooleG.error = event->error;
@@ -397,7 +393,6 @@ static void php_swoole_aio_onFileCompleted(swAio_event *event)
 
     if (event->type == SW_AIO_READ)
     {
-        zcontent = &_zcontent;
         if (ret < 0)
         {
             ZVAL_STRING(zcontent, "");
@@ -411,7 +406,6 @@ static void php_swoole_aio_onFileCompleted(swAio_event *event)
     }
     else if (event->type == SW_AIO_WRITE)
     {
-        zwriten = &_zwriten;
         ZVAL_LONG(zwriten, ret);
         args[0] = *file_req->filename;
         args[1] = *zwriten;
@@ -489,11 +483,11 @@ static void php_swoole_aio_onFileCompleted(swAio_event *event)
         }
     }
 
-    if (zcontent)
+    if (!ZVAL_IS_NULL(zcontent))
     {
         zval_ptr_dtor(zcontent);
     }
-    if (zwriten)
+    if (!ZVAL_IS_NULL(zwriten))
     {
         zval_ptr_dtor(zwriten);
     }
@@ -722,6 +716,7 @@ PHP_FUNCTION(swoole_async_readfile)
     }
     if (!php_swoole_is_callable(callback))
     {
+        close(fd);
         RETURN_FALSE;
     }
 
