@@ -562,7 +562,12 @@ void php_swoole_client_check_setting(swClient *cli, zval *zset)
     {
         convert_to_string(v);
         cli->protocol.package_eof_len = Z_STRLEN_P(v);
-        if (cli->protocol.package_eof_len > SW_DATA_EOF_MAXLEN)
+        if (cli->protocol.package_eof_len == 0)
+        {
+            swoole_php_fatal_error(E_ERROR, "pacakge_eof cannot be an empty string");
+            return;
+        }
+        else if (cli->protocol.package_eof_len > SW_DATA_EOF_MAXLEN)
         {
             swoole_php_fatal_error(E_ERROR, "pacakge_eof max length is %d", SW_DATA_EOF_MAXLEN);
             return;
@@ -886,7 +891,7 @@ void php_swoole_client_free(zval *zobject, swClient *cli)
     swoole_set_object(zobject, NULL);
 }
 
-swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port)
+swClient* php_swoole_client_new(zval *zobject, char *host, int host_len, int port)
 {
     zval *ztype;
     int async = 0;
@@ -895,7 +900,7 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
     uint64_t tmp_buf;
     int ret;
 
-    ztype = sw_zend_read_property(Z_OBJCE_P(object), object, ZEND_STRL("type"), 0);
+    ztype = sw_zend_read_property(Z_OBJCE_P(zobject), zobject, ZEND_STRL("type"), 0);
 
     if (ztype == NULL || ZVAL_IS_NULL(ztype))
     {
@@ -920,15 +925,16 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
 
     swClient *cli;
     bzero(conn_key, SW_LONG_CONNECTION_KEY_LEN);
-    zval *connection_id = sw_zend_read_property(Z_OBJCE_P(object), object, ZEND_STRL("id"), 1);
+    zval *zconnection_id = sw_zend_read_property_not_null(Z_OBJCE_P(zobject), zobject, ZEND_STRL("id"), 1);
 
-    if (connection_id == NULL || ZVAL_IS_NULL(connection_id))
+    if (!zconnection_id)
     {
         conn_key_len = snprintf(conn_key, SW_LONG_CONNECTION_KEY_LEN, "%s:%d", host, port) + 1;
     }
     else
     {
-        conn_key_len = snprintf(conn_key, SW_LONG_CONNECTION_KEY_LEN, "%s", Z_STRVAL_P(connection_id)) + 1;
+        convert_to_string(zconnection_id);
+        conn_key_len = snprintf(conn_key, SW_LONG_CONNECTION_KEY_LEN, "%s", Z_STRVAL_P(zconnection_id)) + 1;
     }
 
     //keep the tcp connection
@@ -955,7 +961,7 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
                 goto create_socket;
             }
             cli->reuse_count ++;
-            zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("reuseCount"), cli->reuse_count);
+            zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("reuseCount"), cli->reuse_count);
         }
     }
     else
@@ -966,7 +972,7 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
         if (swClient_create(cli, php_swoole_socktype(type), async) < 0)
         {
             swoole_php_fatal_error(E_WARNING, "swClient_create() failed. Error: %s [%d]", strerror(errno), errno);
-            zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("errCode"), errno);
+            zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("errCode"), errno);
             return NULL;
         }
 
@@ -975,7 +981,7 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
         cli->server_strlen = conn_key_len;
     }
 
-    zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("sock"), cli->socket->fd);
+    zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("sock"), cli->socket->fd);
 
     if (type & SW_FLAG_KEEP)
     {
@@ -997,7 +1003,7 @@ static PHP_METHOD(swoole_client, __construct)
     long async = 0;
     long type = 0;
     char *id = NULL;
-    zend_size_t len = 0;
+    size_t len = 0;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|ls", &type, &async, &id, &len) == FAILURE)
     {
@@ -1030,10 +1036,6 @@ static PHP_METHOD(swoole_client, __construct)
     {
         zend_update_property_stringl(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("id"), id, len);
     }
-    else
-    {
-        zend_update_property_null(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("id"));
-    }
     //init
     swoole_set_object(getThis(), NULL);
     swoole_set_property(getThis(), client_property_callback, NULL);
@@ -1073,7 +1075,7 @@ static PHP_METHOD(swoole_client, set)
     zval *zset;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zset) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (Z_TYPE_P(zset) != IS_ARRAY)
     {
@@ -1090,23 +1092,16 @@ static PHP_METHOD(swoole_client, connect)
 {
     zend_long port = 0, sock_flag = 0;
     char *host = NULL;
-    zend_size_t host_len;
+    size_t host_len;
     double timeout = SW_CLIENT_DEFAULT_TIMEOUT;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 4)
         Z_PARAM_STRING(host, host_len)
         Z_PARAM_OPTIONAL
         Z_PARAM_LONG(port)
         Z_PARAM_DOUBLE(timeout)
         Z_PARAM_LONG(sock_flag)
-    ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|ldl", &host, &host_len, &port, &timeout, &sock_flag) == FAILURE)
-    {
-        return;
-    }
-#endif
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     if (host_len <= 0)
     {
@@ -1150,7 +1145,7 @@ static PHP_METHOD(swoole_client, connect)
     }
 
     zval *zset = sw_zend_read_property(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
-    if (zset && !ZVAL_IS_NULL(zset))
+    if (zset && ZVAL_IS_ARRAY(zset))
     {
         php_swoole_client_check_setting(cli, zset);
     }
@@ -1255,21 +1250,14 @@ static PHP_METHOD(swoole_client, connect)
 static PHP_METHOD(swoole_client, send)
 {
     char *data;
-    zend_size_t data_len;
+    size_t data_len;
     zend_long flags = 0;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 2)
         Z_PARAM_STRING(data, data_len)
         Z_PARAM_OPTIONAL
         Z_PARAM_LONG(flags)
-    ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|l", &data, &data_len, &flags) == FAILURE)
-    {
-        return;
-    }
-#endif
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     if (data_len <= 0)
     {
@@ -1301,14 +1289,14 @@ static PHP_METHOD(swoole_client, send)
 static PHP_METHOD(swoole_client, sendto)
 {
     char* ip;
-    zend_size_t ip_len;
+    size_t ip_len;
     long port;
     char *data;
-    zend_size_t len;
+    size_t len;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sls", &ip, &ip_len, &port, &data, &len) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (len <= 0)
@@ -1349,13 +1337,13 @@ static PHP_METHOD(swoole_client, sendto)
 static PHP_METHOD(swoole_client, sendfile)
 {
     char *file;
-    zend_size_t file_len;
+    size_t file_len;
     long offset = 0;
     long length = 0;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|ll", &file, &file_len, &offset, &length) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (file_len <= 0)
     {
@@ -1397,18 +1385,11 @@ static PHP_METHOD(swoole_client, recv)
     int ret;
     char *buf = NULL;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(0, 2)
         Z_PARAM_OPTIONAL
         Z_PARAM_LONG(buf_len)
         Z_PARAM_LONG(flags)
-    ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "|ll", &buf_len, &flags) == FAILURE)
-    {
-        return;
-    }
-#endif
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     //waitall
     if (flags == 1)
@@ -1583,14 +1564,20 @@ static PHP_METHOD(swoole_client, recv)
         SwooleG.error = errno;
         swoole_php_error(E_WARNING, "recv() failed. Error: %s [%d]", strerror(SwooleG.error), SwooleG.error);
         zend_update_property_long(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("errCode"), SwooleG.error);
-        swoole_efree(buf);
+        if (buf)
+        {
+            efree(buf);
+        }
         RETURN_FALSE;
     }
     else
     {
         if (ret == 0)
         {
-            swoole_efree(buf);
+            if (buf)
+            {
+                efree(buf);
+            }
             RETURN_EMPTY_STRING();
         }
         else
@@ -1729,17 +1716,10 @@ static PHP_METHOD(swoole_client, close)
     int ret = 1;
     zend_bool force = 0;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(0, 1)
         Z_PARAM_OPTIONAL
         Z_PARAM_BOOL(force)
-    ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "|b", &force) == FAILURE)
-    {
-        return;
-    }
-#endif
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     swClient *cli = (swClient *) swoole_get_object(getThis());
     if (!cli || !cli->socket)
@@ -1779,12 +1759,12 @@ static PHP_METHOD(swoole_client, close)
 static PHP_METHOD(swoole_client, on)
 {
     char *cb_name;
-    zend_size_t cb_name_len;
+    size_t cb_name_len;
     zval *zcallback;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &cb_name, &cb_name_len, &zcallback) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     zval *ztype = sw_zend_read_property(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("type"), 0);
@@ -1908,7 +1888,7 @@ static PHP_METHOD(swoole_client, enableSSL)
     }
     cli->open_ssl = 1;
     zval *zset = sw_zend_read_property(swoole_client_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
-    if (zset && !ZVAL_IS_NULL(zset))
+    if (zset && ZVAL_IS_ARRAY(zset))
     {
         php_swoole_client_check_ssl_setting(cli, zset);
     }
@@ -1921,7 +1901,7 @@ static PHP_METHOD(swoole_client, enableSSL)
         zval *zcallback;
         if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zcallback) == FAILURE)
         {
-            return;
+            RETURN_FALSE;
         }
         char *func_name = NULL;
         zend_fcall_info_cache func_cache;
@@ -1995,7 +1975,7 @@ static PHP_METHOD(swoole_client, verifyPeerCert)
     zend_bool allow_self_signed = 0;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "|b", &allow_self_signed) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     SW_CHECK_RETURN(swClient_ssl_verify(cli, allow_self_signed));
 }
@@ -2011,7 +1991,7 @@ static PHP_METHOD(swoole_client, pipe)
     zval *write_socket;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &write_socket) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     int fd;
@@ -2049,7 +2029,7 @@ static PHP_METHOD(swoole_client, shutdown)
     long __how;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "l", &__how) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     SW_CHECK_RETURN(swClient_shutdown(cli, __how));
 }
@@ -2063,7 +2043,7 @@ PHP_FUNCTION(swoole_client_select)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "a!a!a!|d", &r_array, &w_array, &e_array, &timeout) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     int maxevents = MAX(MAX(php_swoole_array_length(r_array), php_swoole_array_length(w_array)),
@@ -2122,7 +2102,7 @@ PHP_FUNCTION(swoole_client_select)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "a!a!a!|d", &r_array, &w_array, &e_array, &timeout) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     FD_ZERO(&rfds);
