@@ -18,7 +18,7 @@
 #include "php_swoole.h"
 #include "swoole_http_client.h"
 
-static swString *http_client_buffer;
+swString *http_client_buffer;
 
 static void http_client_onReceive(swClient *cli, char *data, uint32_t length);
 static void http_client_onConnect(swClient *cli);
@@ -29,7 +29,7 @@ static void http_client_onResponseException();
 static int http_client_onMessage(swConnection *conn, char *data, uint32_t length);
 
 static int http_client_send_http_request(zval *zobject);
-static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zval *callback);
+static int http_client_execute(zval *zobject, char *uri, size_t uri_len, zval *callback);
 
 #ifdef SW_HAVE_ZLIB
 int http_response_uncompress(z_stream *stream, swString *buffer, char *body, int length);
@@ -174,23 +174,24 @@ static const zend_function_entry swoole_http_client_methods[] =
 
 void http_client_clear_response_properties(zval *zobject)
 {
-    zval *attr;
-    zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("errCode"), 0);
-    zend_update_property_long(Z_OBJCE_P(zobject), zobject, ZEND_STRL("statusCode"), 0);
-    attr = sw_zend_read_property(Z_OBJCE_P(zobject), zobject, ZEND_STRL("headers"), 1);
-    if (Z_TYPE_P(attr) == IS_ARRAY)
+    zval *zattr;
+    zend_class_entry *ce = Z_OBJCE_P(zobject);
+    zend_update_property_long(ce, zobject, ZEND_STRL("errCode"), 0);
+    zend_update_property_long(ce, zobject, ZEND_STRL("statusCode"), 0);
+    zattr = sw_zend_read_property(ce, zobject, ZEND_STRL("headers"), 1);
+    if (Z_TYPE_P(zattr) == IS_ARRAY)
     {
-        zend_hash_clean(Z_ARRVAL_P(attr));
+        zend_hash_clean(Z_ARRVAL_P(zattr));
     }
-    attr = sw_zend_read_property(Z_OBJCE_P(zobject), zobject, ZEND_STRL("set_cookie_headers"), 1);
-    if (Z_TYPE_P(attr) == IS_ARRAY)
+    zattr = sw_zend_read_property(ce, zobject, ZEND_STRL("set_cookie_headers"), 1);
+    if (Z_TYPE_P(zattr) == IS_ARRAY)
     {
-        zend_hash_clean(Z_ARRVAL_P(attr));
+        zend_hash_clean(Z_ARRVAL_P(zattr));
     }
-    zend_update_property_string(Z_OBJCE_P(zobject), zobject, ZEND_STRL("body"), "");
+    zend_update_property_string(ce, zobject, ZEND_STRL("body"), "");
 }
 
-static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zval *callback)
+static int http_client_execute(zval *zobject, char *uri, size_t uri_len, zval *callback)
 {
     if (uri_len <= 0)
     {
@@ -302,6 +303,7 @@ static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zv
         }
         http->download = 1;
         http->file_fd = fd;
+        hcc->download_file = NULL;
     }
 
     //if connection exists
@@ -320,7 +322,7 @@ static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zv
     zval *ztmp;
     HashTable *vht;
     zval *zset = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("setting"), 1);
-    if (zset && !ZVAL_IS_NULL(zset))
+    if (zset && ZVAL_IS_ARRAY(zset))
     {
         vht = Z_ARRVAL_P(zset);
         /**
@@ -352,14 +354,14 @@ static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zv
 
         if (http->cli->http_proxy)
         {
-            zval *send_header = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
-            if (send_header == NULL || Z_TYPE_P(send_header) != IS_ARRAY)
+            zval *zsend_header = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
+            if (zsend_header == NULL || Z_TYPE_P(zsend_header) != IS_ARRAY)
             {
                 swoole_php_fatal_error (E_WARNING, "http proxy must set Host");
                 return SW_ERR;
             }
             zval *value;
-            if (!(value = zend_hash_str_find(Z_ARRVAL_P(send_header), ZEND_STRL("Host"))) ||
+            if (!(value = zend_hash_str_find(Z_ARRVAL_P(zsend_header), ZEND_STRL("Host"))) ||
                     Z_TYPE_P(value) != IS_STRING || Z_STRLEN_P(value) < 1)
             {
                 swoole_php_fatal_error(E_WARNING, "http proxy must set Host");
@@ -375,7 +377,7 @@ static int http_client_execute(zval *zobject, char *uri, zend_size_t uri_len, zv
                 zend_string *str = php_base64_encode((const unsigned char *) _buf1, _n1);
                 int _n2 = snprintf(_buf2, sizeof(_buf2), "Basic %*s", (int)str->len, str->val);
                 zend_string_free(str);
-                add_assoc_stringl_ex(send_header, ZEND_STRL("Proxy-Authorization"), _buf2, _n2);
+                add_assoc_stringl_ex(zsend_header, ZEND_STRL("Proxy-Authorization"), _buf2, _n2);
             }
         }
     }
@@ -409,7 +411,6 @@ void swoole_http_client_init(int module_number)
 
     zend_declare_property_long(swoole_http_client_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC);
     zend_declare_property_long(swoole_http_client_class_entry_ptr, ZEND_STRL("errCode"), 0, ZEND_ACC_PUBLIC);
-    zend_declare_property_long(swoole_http_client_class_entry_ptr, ZEND_STRL("sock"), 0, ZEND_ACC_PUBLIC);
     zend_declare_property_long(swoole_http_client_class_entry_ptr, ZEND_STRL("statusCode"), 0, ZEND_ACC_PUBLIC);
     zend_declare_property_null(swoole_http_client_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC);
     zend_declare_property_long(swoole_http_client_class_entry_ptr, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC);
@@ -435,6 +436,13 @@ void swoole_http_client_init(int module_number)
         swoole_php_fatal_error(E_ERROR, "[1] swString_new(%d) failed.", SW_HTTP_RESPONSE_INIT_SIZE);
     }
 
+#ifdef SW_HAVE_ZLIB
+    swoole_zlib_buffer = swString_new(SW_HTTP_RESPONSE_INIT_SIZE);
+    if (!swoole_zlib_buffer)
+    {
+        swoole_php_fatal_error(E_ERROR, "[2] swString_new(%d) failed.", SW_HTTP_RESPONSE_INIT_SIZE);
+    }
+#endif
 }
 
 static void http_client_execute_callback(zval *zobject, enum php_swoole_client_callback_type type)
@@ -594,12 +602,12 @@ static void http_client_onRequestTimeout(swTimer *timer, swTimer_node *tnode)
 
     if (cli->buffer && cli->buffer->length > 0) // received something bug not complete
     {
-        zval *headers = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
-        zval *value;
-        if (php_swoole_array_get_value(Z_ARRVAL_P(headers), "Connection", value))
+        zval *zheaders = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
+        zval *v;
+        if (php_swoole_array_get_value(Z_ARRVAL_P(zheaders), "Connection", v))
         {
-            convert_to_string(value);
-            if (strcmp(Z_STRVAL_P(value), "Upgrade") == 0) // is upgrade
+            convert_to_string(v);
+            if (strcmp(Z_STRVAL_P(v), "Upgrade") == 0) // is upgrade
             {
                 hcc->error_flag |= HTTP_CLIENT_EFLAG_UPGRADE;
             }
@@ -811,12 +819,12 @@ static int http_client_send_http_request(zval *zobject)
 
     http_client_property *hcc = swoole_get_property(zobject, 0);
 
-    zval *post_data = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestBody"), 1);
-    zval *send_header = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
+    zval *zpost_data = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestBody"), 1);
+    zval *zsend_header = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestHeaders"), 1);
     uint32_t header_flag = 0x0;
 
     //POST
-    if (post_data && !ZVAL_IS_NULL(post_data))
+    if (zpost_data && !ZVAL_IS_NULL(zpost_data))
     {
         if (hcc->request_method == NULL)
         {
@@ -849,7 +857,7 @@ static int http_client_send_http_request(zval *zobject)
     if (http->cli->http_proxy)
 #endif
     {
-        value = zend_hash_str_find(Z_ARRVAL_P(send_header), ZEND_STRL("Host")); //checked before
+        value = zend_hash_str_find(Z_ARRVAL_P(zsend_header), ZEND_STRL("Host")); //checked before
         char *pre = "http://";
         int len = http->uri_len + Z_STRLEN_P(value) + strlen(pre) + 10;
         void *addr = emalloc(http->uri_len + Z_STRLEN_P(value) + strlen(pre) + 10);
@@ -860,11 +868,11 @@ static int http_client_send_http_request(zval *zobject)
     swString_append_ptr (http_client_buffer, http->uri, http->uri_len);
     swString_append_ptr(http_client_buffer, ZEND_STRL(" HTTP/1.1\r\n"));
 
-    if (send_header && Z_TYPE_P(send_header) == IS_ARRAY)
+    if (zsend_header && Z_TYPE_P(zsend_header) == IS_ARRAY)
     {
         // As much as possible to ensure that Host is the first header.
         // See: http://tools.ietf.org/html/rfc7230#section-5.4
-        if ((value = zend_hash_str_find(Z_ARRVAL_P(send_header), ZEND_STRL("Host"))) || (value = zend_hash_str_find(Z_ARRVAL_P(send_header), ZEND_STRL("host"))))
+        if ((value = zend_hash_str_find(Z_ARRVAL_P(zsend_header), ZEND_STRL("Host"))) || (value = zend_hash_str_find(Z_ARRVAL_P(zsend_header), ZEND_STRL("host"))))
         {
             http_client_swString_append_headers(http_client_buffer, ZEND_STRL("Host"), Z_STRVAL_P(value), Z_STRLEN_P(value));
         }
@@ -873,7 +881,7 @@ static int http_client_send_http_request(zval *zobject)
             http_client_swString_append_headers(http_client_buffer, ZEND_STRL("Host"), http->host, http->host_len);
         }
 
-        SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(send_header), key, keylen, keytype, value)
+        SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(zsend_header), key, keylen, keytype, value)
             if (HASH_KEY_IS_STRING != keytype)
             {
                 continue;
@@ -922,15 +930,15 @@ static int http_client_send_http_request(zval *zobject)
     }
 #endif
 
-    zval *cookies = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("cookies"), 1);
-    if (cookies && Z_TYPE_P(cookies) == IS_ARRAY)
+    zval *zcookies = sw_zend_read_property(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("cookies"), 1);
+    if (zcookies && Z_TYPE_P(zcookies) == IS_ARRAY)
     {
         swString_append_ptr(http_client_buffer, ZEND_STRL("Cookie: "));
-        int n_cookie = Z_ARRVAL_P(cookies)->nNumOfElements;
+        int n_cookie = Z_ARRVAL_P(zcookies)->nNumOfElements;
         int i = 0;
         char *encoded_value;
 
-        SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(cookies), key, keylen, keytype, value)
+        SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(zcookies), key, keylen, keytype, value)
             i ++;
             if (HASH_KEY_IS_STRING != keytype)
             {
@@ -978,9 +986,9 @@ static int http_client_send_http_request(zval *zobject)
         int content_length = 0;
 
         //post data
-        if (Z_TYPE_P(post_data) == IS_ARRAY && php_swoole_array_length(post_data) > 0)
+        if (Z_TYPE_P(zpost_data) == IS_ARRAY && php_swoole_array_length(zpost_data) > 0)
         {
-            SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(post_data), key, keylen, keytype, value)
+            SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(zpost_data), key, keylen, keytype, value)
                 if (HASH_KEY_IS_STRING != keytype)
                 {
                     continue;
@@ -1030,9 +1038,9 @@ static int http_client_send_http_request(zval *zobject)
         http_client_append_content_length(http_client_buffer, content_length + sizeof(boundary_str) - 1 + 6);
 
         //post data
-        if (Z_TYPE_P(post_data) == IS_ARRAY && php_swoole_array_length(post_data) > 0)
+        if (Z_TYPE_P(zpost_data) == IS_ARRAY && php_swoole_array_length(zpost_data) > 0)
         {
-            SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(post_data), key, keylen, keytype, value)
+            SW_HASHTABLE_FOREACH_START2(Z_ARRVAL_P(zpost_data), key, keylen, keytype, value)
                 if (HASH_KEY_IS_STRING != keytype)
                 {
                     continue;
@@ -1112,16 +1120,16 @@ static int http_client_send_http_request(zval *zobject)
         }
     }
     //x-www-form-urlencoded or raw
-    else if (post_data && !ZVAL_IS_NULL(post_data))
+    else if (zpost_data && !ZVAL_IS_NULL(zpost_data))
     {
-        if (Z_TYPE_P(post_data) == IS_ARRAY)
+        if (Z_TYPE_P(zpost_data) == IS_ARRAY)
         {
-            zend_size_t len;
+            size_t len;
             http_client_swString_append_headers(http_client_buffer, ZEND_STRL("Content-Type"), ZEND_STRL("application/x-www-form-urlencoded"));
-            if (php_swoole_array_length(post_data) > 0) //if it's an empty array, http build will fail
+            if (php_swoole_array_length(zpost_data) > 0) //if it's an empty array, http build will fail
             {
                 smart_str formstr_s = { 0 };
-                char *formstr = sw_http_build_query(post_data, &len, &formstr_s);
+                char *formstr = sw_http_build_query(zpost_data, &len, &formstr_s);
                 if (formstr == NULL)
                 {
                     swoole_php_error(E_WARNING, "http_build_query failed.");
@@ -1143,16 +1151,16 @@ static int http_client_send_http_request(zval *zobject)
             //cleanup request body
             zend_update_property_null(swoole_http_client_class_entry_ptr, zobject, ZEND_STRL("requestBody"));
         }
-        else if (Z_TYPE_P(post_data) == IS_STRING && Z_STRLEN_P(post_data) > 0)
+        else if (Z_TYPE_P(zpost_data) == IS_STRING && Z_STRLEN_P(zpost_data) > 0)
         {
-            http_client_append_content_length(http_client_buffer, Z_STRLEN_P(post_data));
+            http_client_append_content_length(http_client_buffer, Z_STRLEN_P(zpost_data));
             //send http header
             if ((ret = http->cli->send(http->cli, http_client_buffer->str, http_client_buffer->length, 0)) < 0)
             {
                 goto send_fail;
             }
             //send http body
-            if ((ret = http->cli->send(http->cli, Z_STRVAL_P(post_data), Z_STRLEN_P(post_data), 0)) < 0)
+            if ((ret = http->cli->send(http->cli, Z_STRVAL_P(zpost_data), Z_STRLEN_P(zpost_data), 0)) < 0)
             {
                 goto send_fail;
             }
@@ -1258,12 +1266,12 @@ void http_client_reset(http_client *http)
     http->state = HTTP_CLIENT_STATE_READY;
 }
 
-void http_client_free(zval *object)
+uint8_t http_client_free(zval *zobject)
 {
-    http_client *http = swoole_get_object(object);
+    http_client *http = swoole_get_object(zobject);
     if (!http)
     {
-        return;
+        return 0;
     }
     if (http->uri)
     {
@@ -1279,15 +1287,20 @@ void http_client_free(zval *object)
     swClient *cli = http->cli;
     if (cli)
     {
-        php_swoole_client_free(object, cli);
+        php_swoole_client_free(zobject, cli);
         http->cli = NULL;
     }
     efree(http);
 
-    swTraceLog(SW_TRACE_HTTP_CLIENT, "free, object handle=%d.", Z_OBJ_HANDLE_P(object));
+    //unset http_client
+    swoole_set_object(zobject, NULL);
+
+    swTraceLog(SW_TRACE_HTTP_CLIENT, "free, object handle=%d.", Z_OBJ_HANDLE_P(zobject));
+
+    return 1;
 }
 
-http_client* http_client_create(zval *object)
+http_client* http_client_create(zval *zobject)
 {
     zval *ztmp;
     http_client *http;
@@ -1295,26 +1308,27 @@ http_client* http_client_create(zval *object)
     http = (http_client*) emalloc(sizeof(http_client));
     bzero(http, sizeof(http_client));
 
-    swoole_set_object(object, http);
+    swoole_set_object(zobject, http);
 
     swoole_http_parser_init(&http->parser, PHP_HTTP_RESPONSE);
     http->parser.data = http;
 
-    ztmp = sw_zend_read_property(Z_OBJCE_P(object), object, ZEND_STRL("host"), 0);
+    ztmp = sw_zend_read_property(Z_OBJCE_P(zobject), zobject, ZEND_STRL("host"), 0);
+    convert_to_string(ztmp);
     http->host = Z_STRVAL_P(ztmp);
     http->host_len = Z_STRLEN_P(ztmp);
 
-    ztmp = sw_zend_read_property(Z_OBJCE_P(object), object, ZEND_STRL("port"), 0);
+    ztmp = sw_zend_read_property(Z_OBJCE_P(zobject), zobject, ZEND_STRL("port"), 0);
     convert_to_long(ztmp);
     http->port = Z_LVAL_P(ztmp);
 
     http->timeout = SW_CLIENT_DEFAULT_TIMEOUT;
     http->keep_alive = 1;
     http->state = HTTP_CLIENT_STATE_READY;
-    http->object = object;
+    http->object = zobject;
     sw_copy_to_stack(http->object, http->_object);
 
-    swTraceLog(SW_TRACE_HTTP_CLIENT, "create, object handle=%d.", Z_OBJ_HANDLE_P(object));
+    swTraceLog(SW_TRACE_HTTP_CLIENT, "create, object handle=%d.", Z_OBJ_HANDLE_P(zobject));
 
     return http;
 }
@@ -1322,13 +1336,13 @@ http_client* http_client_create(zval *object)
 static PHP_METHOD(swoole_http_client, __construct)
 {
     char *host;
-    zend_size_t host_len;
+    size_t host_len;
     long port = 80;
     zend_bool ssl = SW_FALSE;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|lb", &host, &host_len, &port, &ssl) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (host_len <= 0)
@@ -1403,7 +1417,7 @@ static PHP_METHOD(swoole_http_client, set)
     zval *zset;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zset) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (Z_TYPE_P(zset) != IS_ARRAY)
     {
@@ -1421,11 +1435,11 @@ static PHP_METHOD(swoole_http_client, setHeaders)
     zval *headers;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &headers) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
-    zval *headers_property = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestHeaders"), 1);
-    php_array_merge(Z_ARRVAL_P(headers_property), Z_ARRVAL_P(headers));
+    zval *zheaders = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestHeaders"), 1);
+    php_array_merge(Z_ARRVAL_P(zheaders), Z_ARRVAL_P(headers));
 
     RETURN_TRUE;
 }
@@ -1435,11 +1449,11 @@ static PHP_METHOD(swoole_http_client, setCookies)
     zval *cookies;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &cookies) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
-    zval *cookies_property = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("cookies"), 1);
-    php_array_merge(Z_ARRVAL_P(cookies_property), Z_ARRVAL_P(cookies));
+    zval *zcookies = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("cookies"), 1);
+    php_array_merge(Z_ARRVAL_P(zcookies), Z_ARRVAL_P(cookies));
 
     RETURN_TRUE;
 }
@@ -1449,7 +1463,7 @@ static PHP_METHOD(swoole_http_client, setData)
     zval *data;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &data) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (http_client_check_data(data) < 0)
     {
@@ -1457,8 +1471,8 @@ static PHP_METHOD(swoole_http_client, setData)
     }
     if (Z_TYPE_P(data) == IS_ARRAY)
     {
-        zval *data_property = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestBody"), 1);
-        php_array_merge(Z_ARRVAL_P(data_property), Z_ARRVAL_P(data));
+        zval *zbody = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestBody"), 1);
+        php_array_merge(Z_ARRVAL_P(zbody), Z_ARRVAL_P(data));
     }
     else
     {
@@ -1470,13 +1484,13 @@ static PHP_METHOD(swoole_http_client, setData)
 static PHP_METHOD(swoole_http_client, addFile)
 {
     char *path;
-    zend_size_t l_path;
+    size_t l_path;
     char *name;
-    zend_size_t l_name;
+    size_t l_name;
     char *type = NULL;
-    zend_size_t l_type;
+    size_t l_type;
     char *filename = NULL;
-    zend_size_t l_filename;
+    size_t l_filename;
     long offset = 0;
     long length = 0;
 
@@ -1569,10 +1583,10 @@ static PHP_METHOD(swoole_http_client, addFile)
 static PHP_METHOD(swoole_http_client, setMethod)
 {
     char *method;
-    zend_size_t length = 0;
+    size_t length = 0;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &method, &length) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     int http_method = swHttp_get_method(method, length + 1);
@@ -1648,12 +1662,12 @@ static PHP_METHOD(swoole_http_client, close)
 static PHP_METHOD(swoole_http_client, on)
 {
     char *cb_name;
-    zend_size_t cb_name_len;
+    size_t cb_name_len;
     zval *zcallback;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &cb_name, &cb_name_len, &zcallback) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
 #ifdef PHP_SWOOLE_CHECK_CALLBACK
@@ -1715,10 +1729,10 @@ int http_client_parser_on_header_value(swoole_http_parser *parser, const char *a
 {
     http_client* http = (http_client*) parser->data;
     zval* zobject = (zval*) http->object;
-    zval *headers = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("headers"), 1);
+    zval *zheaders = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("headers"), 1);
 
     char *header_name = zend_str_tolower_dup(http->tmp_header_field_name, http->tmp_header_field_name_len);
-    add_assoc_stringl_ex(headers, header_name, http->tmp_header_field_name_len, (char *) at, length);
+    add_assoc_stringl_ex(zheaders, header_name, http->tmp_header_field_name_len, (char *) at, length);
 
     //websocket client
     if (strcasecmp(header_name, "Upgrade") == 0 && strncasecmp(at, "websocket", length) == 0)
@@ -1727,9 +1741,9 @@ int http_client_parser_on_header_value(swoole_http_parser *parser, const char *a
     }
     else if (strcasecmp(header_name, "Set-Cookie") == 0)
     {
-        zval *cookies = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("cookies"), 1);
-        zval *set_cookie_headers = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("set_cookie_headers"), 1);
-        if (SW_OK != http_parse_set_cookies(at, length, cookies, set_cookie_headers))
+        zval *zcookies = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("cookies"), 1);
+        zval *zset_cookie_headers = sw_zend_read_property_array(Z_OBJCE_P(zobject), zobject, ZEND_STRL("set_cookie_headers"), 1);
+        if (SW_OK != http_parse_set_cookies(at, length, zcookies, zset_cookie_headers))
         {
             efree(header_name);
             return SW_ERR;
@@ -1855,7 +1869,7 @@ int http_client_parser_on_body(swoole_http_parser *parser, const char *at, size_
 #ifdef SW_HAVE_ZLIB
         if (http->gzip)
         {
-            if (http_response_uncompress(&http->gzip_stream, http->gzip_buffer, http->body->str, http->body->length))
+            if (http_response_uncompress(&http->gzip_stream, http->gzip_buffer, http->body->str, http->body->length) != SW_OK)
             {
                 return -1;
             }
@@ -1949,12 +1963,12 @@ static PHP_METHOD(swoole_http_client, execute)
 {
     int ret;
     char *uri = NULL;
-    zend_size_t uri_len = 0;
+    size_t uri_len = 0;
     zval *finish_cb;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &uri, &uri_len, &finish_cb) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     http_client_property *hcc = swoole_get_property(getThis(), 0);
     if (hcc->shutdown)
@@ -1970,12 +1984,12 @@ static PHP_METHOD(swoole_http_client, get)
 {
     int ret;
     char *uri = NULL;
-    zend_size_t uri_len = 0;
+    size_t uri_len = 0;
     zval *finish_cb;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &uri, &uri_len, &finish_cb) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     http_client_property *hcc = swoole_get_property(getThis(), 0);
     if (hcc->shutdown)
@@ -1991,14 +2005,14 @@ static PHP_METHOD(swoole_http_client, download)
 {
     int ret;
     char *uri = NULL;
-    zend_size_t uri_len = 0;
+    size_t uri_len = 0;
     zval *finish_cb;
     zval *download_file;
     off_t offset = 0;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "szz|l", &uri, &uri_len, &download_file, &finish_cb, &offset) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     http_client_property *hcc = swoole_get_property(getThis(), 0);
@@ -2019,13 +2033,13 @@ static PHP_METHOD(swoole_http_client, post)
 {
     int ret;
     char *uri = NULL;
-    zend_size_t uri_len = 0;
+    size_t uri_len = 0;
     zval *callback;
     zval *data;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "szz", &uri, &uri_len, &data, &callback) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
     if (http_client_check_data(data) < 0)
     {
@@ -2040,8 +2054,8 @@ static PHP_METHOD(swoole_http_client, post)
     }
     if (Z_TYPE_P(data) == IS_ARRAY)
     {
-        zval *data_property = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestBody"), 1);
-        php_array_merge(Z_ARRVAL_P(data_property), Z_ARRVAL_P(data));
+        zval *zbody = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestBody"), 1);
+        php_array_merge(Z_ARRVAL_P(zbody), Z_ARRVAL_P(data));
     }
     else
     {
@@ -2055,12 +2069,12 @@ static PHP_METHOD(swoole_http_client, upgrade)
 {
     int ret;
     char *uri = NULL;
-    zend_size_t uri_len = 0;
+    size_t uri_len = 0;
     zval *finish_cb;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &uri, &uri_len, &finish_cb) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     http_client_property *hcc = swoole_get_property(getThis(), 0);
@@ -2075,17 +2089,17 @@ static PHP_METHOD(swoole_http_client, upgrade)
         return;
     }
 
-    zval *headers = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestHeaders"), 1);
+    zval *zheaders = sw_zend_read_property_array(swoole_http_client_class_entry_ptr, getThis(), ZEND_STRL("requestHeaders"), 1);
 
     char buf[SW_WEBSOCKET_KEY_LENGTH + 1];
     http_client_create_token(SW_WEBSOCKET_KEY_LENGTH, buf);
 
-    add_assoc_string(headers, "Connection", "Upgrade");
-    add_assoc_string(headers, "Upgrade", "websocket");
-    add_assoc_string(headers, "Sec-WebSocket-Version", SW_WEBSOCKET_VERSION);
+    add_assoc_string(zheaders, "Connection", "Upgrade");
+    add_assoc_string(zheaders, "Upgrade", "websocket");
+    add_assoc_string(zheaders, "Sec-WebSocket-Version", SW_WEBSOCKET_VERSION);
 
     zend_string *str = php_base64_encode((const unsigned char *) buf, SW_WEBSOCKET_KEY_LENGTH);
-    add_assoc_str_ex(headers, ZEND_STRL("Sec-WebSocket-Key"), str);
+    add_assoc_str_ex(zheaders, ZEND_STRL("Sec-WebSocket-Key"), str);
 
     ret = http_client_execute(getThis(), uri, uri_len, finish_cb);
     SW_CHECK_RETURN(ret);
@@ -2099,7 +2113,7 @@ static PHP_METHOD(swoole_http_client, push)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|lb", &zdata, &opcode, &fin) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (unlikely(opcode > SW_WEBSOCKET_OPCODE_MAX))
