@@ -211,6 +211,9 @@ int mysql_query(zval *zobject, mysql_client *client, swString *sql, zval *callba
 
 static int swoole_mysql_coro_execute(zval *zobject, mysql_client *client, zval *params)
 {
+
+    sw_coro_check_bind("mysql client", client->cid);
+
     if (!client->cli)
     {
         swoole_php_fatal_error(E_WARNING, "mysql connection#%d is closed.", client->fd);
@@ -603,10 +606,9 @@ static PHP_METHOD(swoole_mysql_coro, connect)
     zval *server_info;
     char buf[2048];
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "a", &server_info) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
+    ZEND_PARSE_PARAMETERS_START(1, 1)
+        Z_PARAM_ARRAY(server_info)
+    ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     php_swoole_array_separate(server_info);
 
@@ -833,17 +835,13 @@ static PHP_METHOD(swoole_mysql_coro, query)
         RETURN_FALSE;
     }
 
-    if (unlikely(client->cid && client->cid != sw_get_current_cid()))
-    {
-        swoole_php_fatal_error(E_ERROR, "mysql client has already been bound to another coroutine.");
-        RETURN_FALSE;
-    }
+    sw_coro_check_bind("mysql client", client->cid);
 
     double timeout = -1;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|d", &sql.str, &sql.length, &timeout) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (sql.length <= 0)
@@ -888,11 +886,7 @@ static void swoole_mysql_coro_query_transcation(const char* command, uint8_t in_
         RETURN_FALSE;
     }
 
-    if (unlikely(client->cid && client->cid != sw_get_current_cid()))
-    {
-        swoole_php_fatal_error(E_ERROR, "mysql client has already been bound to another coroutine.");
-        RETURN_FALSE;
-    }
+    sw_coro_check_bind("mysql client", client->cid);
 
     // we deny the dangerous operation of transaction
     // if developers need use defer to begin transaction, they can use query("begin/commit/rollback") with defer
@@ -972,7 +966,7 @@ static PHP_METHOD(swoole_mysql_coro, setDefer)
     zend_bool defer = 1;
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "|b", &defer) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     mysql_client *client = (mysql_client *) swoole_get_object(getThis());
@@ -994,11 +988,7 @@ static PHP_METHOD(swoole_mysql_coro, recv)
         RETURN_FALSE;
     }
 
-    if (unlikely(client->cid && client->cid != sw_get_current_cid()))
-    {
-        swoole_php_fatal_error(E_ERROR, "mysql client has already been bound to another coroutine.");
-        RETURN_FALSE;
-    }
+    sw_coro_check_bind("mysql client", client->cid);
 
     if (client->iowait == SW_MYSQL_CORO_STATUS_DONE)
     {
@@ -1043,11 +1033,7 @@ static PHP_METHOD(swoole_mysql_coro, prepare)
         RETURN_FALSE;
     }
 
-    if (unlikely(client->cid && client->cid != sw_get_current_cid()))
-    {
-        swoole_php_fatal_error(E_ERROR, "mysql client has already been bound to another coroutine.");
-        RETURN_FALSE;
-    }
+    sw_coro_check_bind("mysql client", client->cid);
 
     double timeout = -1;
 
@@ -1117,11 +1103,6 @@ static PHP_METHOD(swoole_mysql_coro_statement, execute)
         swoole_php_fatal_error(E_WARNING, "mysql connection#%d is closed.", client->fd);
         RETURN_FALSE;
     }
-    if (unlikely(client->cid && client->cid != sw_get_current_cid()))
-    {
-        swoole_php_fatal_error(E_ERROR, "mysql client has already been bound to another coroutine.");
-        RETURN_FALSE;
-    }
 
     double timeout = -1;
 
@@ -1296,7 +1277,7 @@ static PHP_METHOD(swoole_mysql_coro, escape)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|l", &str.str, &str.length, &flags) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (str.length <= 0)
@@ -1778,6 +1759,7 @@ static int swoole_mysql_coro_onRead(swReactor *reactor, swEvent *event)
                 case SW_WAIT:
                     if ((size_t) client->check_offset == buffer->length)
                     {
+                        // check all of the package but not complete
                         return SW_OK;
                     }
                     else
