@@ -470,7 +470,7 @@ static PHP_METHOD(swoole_process, signal)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "lz", &signo, &callback) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (!SWOOLE_G(cli))
@@ -567,7 +567,7 @@ static PHP_METHOD(swoole_process, alarm)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|l", &usec, &type) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (!SWOOLE_G(cli))
@@ -648,7 +648,7 @@ static void php_swoole_onSignal(int signo)
     zval_ptr_dtor(zsigno);
 }
 
-int php_swoole_process_start(swWorker *process, zval *object)
+int php_swoole_process_start(swWorker *process, zval *zobject)
 {
     process->pipe = process->pipe_worker;
     process->pid = getpid();
@@ -703,10 +703,10 @@ int php_swoole_process_start(swWorker *process, zval *object)
 
     swSignal_clear();
 
-    zend_update_property_long(swoole_process_class_entry_ptr, object, ZEND_STRL("pid"), process->pid);
-    zend_update_property_long(swoole_process_class_entry_ptr, object, ZEND_STRL("pipe"), process->pipe_worker);
+    zend_update_property_long(swoole_process_class_entry_ptr, zobject, ZEND_STRL("pid"), process->pid);
+    zend_update_property_long(swoole_process_class_entry_ptr, zobject, ZEND_STRL("pipe"), process->pipe_worker);
 
-    zval *zcallback = sw_zend_read_property(swoole_process_class_entry_ptr, object, ZEND_STRL("callback"), 0);
+    zval *zcallback = sw_zend_read_property(swoole_process_class_entry_ptr, zobject, ZEND_STRL("callback"), 0);
     zval args[1];
 
     if (zcallback == NULL || ZVAL_IS_NULL(zcallback))
@@ -716,8 +716,8 @@ int php_swoole_process_start(swWorker *process, zval *object)
     }
 
     zval *retval = NULL;
-    args[0] = *object;
-    Z_TRY_ADDREF_P(object);
+    args[0] = *zobject;
+    Z_TRY_ADDREF_P(zobject);
 
     if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 1, args, 0, NULL) == FAILURE)
     {
@@ -815,7 +815,7 @@ static PHP_METHOD(swoole_process, read)
 static PHP_METHOD(swoole_process, write)
 {
     char *data = NULL;
-    zend_size_t data_len = 0;
+    size_t data_len = 0;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &data, &data_len) == FAILURE)
     {
@@ -866,7 +866,7 @@ static PHP_METHOD(swoole_process, write)
 static PHP_METHOD(swoole_process, push)
 {
     char *data;
-    zend_size_t length;
+    size_t length;
 
     struct
     {
@@ -955,7 +955,7 @@ static PHP_METHOD(swoole_process, pop)
 static PHP_METHOD(swoole_process, exec)
 {
     char *execfile = NULL;
-    zend_size_t execfile_len = 0;
+    size_t execfile_len = 0;
     zval *args;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sa", &execfile, &execfile_len, &args) == FAILURE)
