@@ -265,7 +265,7 @@ static PHP_METHOD(swoole_process_pool, __construct)
 static PHP_METHOD(swoole_process_pool, on)
 {
     char *name;
-    zend_size_t l_name;
+    size_t l_name;
     zval *callback;
 
     swProcessPool *pool = swoole_get_object(getThis());
@@ -278,7 +278,7 @@ static PHP_METHOD(swoole_process_pool, on)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &name, &l_name, &callback) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (!php_swoole_is_callable(callback))
@@ -336,7 +336,7 @@ static PHP_METHOD(swoole_process_pool, on)
 static PHP_METHOD(swoole_process_pool, listen)
 {
     char *host;
-    zend_size_t l_host;
+    size_t l_host;
     long port;
     long backlog = 2048;
 
@@ -350,7 +350,7 @@ static PHP_METHOD(swoole_process_pool, listen)
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|ll", &host, &l_host, &port, &backlog) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     if (pool->ipc_mode != SW_IPC_SOCKET)
@@ -376,11 +376,11 @@ static PHP_METHOD(swoole_process_pool, listen)
 static PHP_METHOD(swoole_process_pool, write)
 {
     char *data;
-    zend_size_t length;
+    size_t length;
 
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &data, &length) == FAILURE)
     {
-        return;
+        RETURN_FALSE;
     }
 
     swProcessPool *pool = swoole_get_object(getThis());
