@@ -1,15 +1,23 @@
 <?php
-require_once __DIR__ . '/swoole.inc';
+require  __DIR__ . '/config.php';
 
-define('TESTS_ROOT_PATH', dirname(__DIR__));
-
-ini_set("assert.active", 1);
+ini_set('memory_limit', '1024M');
+ini_set('swoole.aio_mode', SWOOLE_AIO_BASE); // SWOOLE_AIO_BASE, SWOOLE_AIO_LINUX
 ini_set('swoole.display_errors', 'Off');
+ini_set("assert.active", 1);
 assert_options(ASSERT_ACTIVE, 1);
 assert_options(ASSERT_WARNING, 1);
 assert_options(ASSERT_BAIL, 0);
 assert_options(ASSERT_QUIET_EVAL, 0);
 
+swoole_async_set([
+    'socket_dontwait' => 1,
+    'aio_mode' => SWOOLE_AIO_BASE,
+    'thread_num' => 1,
+    'disable_dns_cache' => true,
+    'dns_lookup_random' => true,
+]);
+
 if (empty(getenv('SWOOLE_DEBUG'))) {
     if (method_exists('co', 'set')) {
         co::set([
