@@ -46,6 +46,7 @@ if (IS_MAC_OS) {
 }
 
 /** ============== Files ============== */
+define('SOURCE_ROOT_PATH', __DIR__ . '/../../');
 define('TEST_IMAGE', __DIR__ . '/../../examples/test.jpg');
 define('TEST_LOG_FILE', '/tmp/swoole.log');
 define('SSL_FILE_DIR', __DIR__ . '/api/swoole_http_server/localhost-ssl');
@@ -54,4 +55,5 @@ define('SSL_FILE_DIR', __DIR__ . '/api/swoole_http_server/localhost-ssl');
 define('MAX_CONCURRENCY', IS_IN_TRAVIS ? 50 : 200);
 define('MAX_CONCURRENCY_MID', IS_IN_TRAVIS ? 35 : 100);
 define('MAX_CONCURRENCY_LOW', IS_IN_TRAVIS ? 20 : 50);
-define('MAX_REQUESTS', IS_IN_TRAVIS ? 50 : 100);
\ No newline at end of file
+define('MAX_REQUESTS', IS_IN_TRAVIS ? 50 : 100);
+define('MAX_REQUESTS_LOW', IS_IN_TRAVIS ? 10 : 25);
\ No newline at end of file
